==> ideaIC-173.4301.1-sources.jar: org/jetbrains/uast/evaluation/UEvaluatorExtension.kt <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.uast.evaluation

import com.intellij.lang.Language
import com.intellij.openapi.extensions.ExtensionPointName
import com.intellij.psi.PsiMethod
import org.jetbrains.uast.*
import org.jetbrains.uast.values.UValue

interface UEvaluatorExtension {

  companion object {
    val EXTENSION_POINT_NAME: ExtensionPointName<UEvaluatorExtension> =
      ExtensionPointName.create<UEvaluatorExtension>("org.jetbrains.uast.evaluation.UEvaluatorExtension")
  }

  infix fun UValue.to(state: UEvaluationState) = UEvaluationInfo(this, state)

  val language: Language

  fun evaluatePostfix(
    operator: UastPostfixOperator,
    operandValue: UValue,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluatePrefix(
    operator: UastPrefixOperator,
    operandValue: UValue,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluateBinary(
    binaryExpression: UBinaryExpression,
    leftValue: UValue,
    rightValue: UValue,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluateQualified(
    accessType: UastQualifiedExpressionAccessType,
    receiverInfo: UEvaluationInfo,
    selectorInfo: UEvaluationInfo
  ): UEvaluationInfo

  fun evaluateMethodCall(
    target: PsiMethod,
    argumentValues: List<UValue>,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluateVariable(
    variable: UVariable,
    state: UEvaluationState
  ): UEvaluationInfo
}

==> ideaIC-191.4212.41-sources.jar: org/jetbrains/uast/evaluation/UEvaluatorExtension.kt <==
/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jetbrains.uast.evaluation

import com.intellij.lang.Language
import com.intellij.openapi.extensions.ExtensionPointName
import com.intellij.psi.PsiMethod
import org.jetbrains.uast.*
import org.jetbrains.uast.values.UValue

interface UEvaluatorExtension {

  companion object {
    val EXTENSION_POINT_NAME: ExtensionPointName<UEvaluatorExtension> =
      ExtensionPointName.create<UEvaluatorExtension>("org.jetbrains.uast.evaluation.UEvaluatorExtension")
  }

  @Deprecated("kept for binary compatibility, will be removed in IDEA 2019.2",
              ReplaceWith("org.jetbrains.uast.evaluation.UEvaluationInfoKt.to"))
  fun UValue.to(state: UEvaluationState): UEvaluationInfo = UEvaluationInfo(this, state)

  val language: Language

  fun evaluatePostfix(
    operator: UastPostfixOperator,
    operandValue: UValue,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluatePrefix(
    operator: UastPrefixOperator,
    operandValue: UValue,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluateBinary(
    binaryExpression: UBinaryExpression,
    leftValue: UValue,
    rightValue: UValue,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluateQualified(
    accessType: UastQualifiedExpressionAccessType,
    receiverInfo: UEvaluationInfo,
    selectorInfo: UEvaluationInfo
  ): UEvaluationInfo

  fun evaluateMethodCall(
    target: PsiMethod,
    argumentValues: List<UValue>,
    state: UEvaluationState
  ): UEvaluationInfo

  fun evaluateVariable(
    variable: UVariable,
    state: UEvaluationState
  ): UEvaluationInfo
}
